==> v1.3.x.zip: opentelemetry-java-instrumentation/instrumentation/aws-sdk/aws-sdk-1.11/library/src/main/java/io/opentelemetry/instrumentation/awssdk/v1_11/SqsReceiveMessageRequestAccess.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.instrumentation.awssdk.v1_11;

import static java.lang.invoke.MethodType.methodType;

import com.amazonaws.AmazonWebServiceRequest;
import java.lang.invoke.MethodHandle;
import java.lang.invoke.MethodHandles;
import java.util.Collections;
import java.util.List;
import org.checkerframework.checker.nullness.qual.Nullable;

/**
 * Reflective access to aws-sdk-java-sqs class ReceiveMessageRequest.
 *
 * <p>We currently don't have a good pattern of instrumenting a core library with various plugins
 * that need plugin-specific instrumentation - if we accessed the class directly, Muzzle would
 * prevent the entire instrumentation from loading when the plugin isn't available. We need to
 * carefully check this class has all reflection errors result in no-op, and in the future we will
 * hopefully come up with a better pattern.
 */
final class SqsReceiveMessageRequestAccess {

  @Nullable private static final MethodHandle WITH_ATTRIBUTE_NAMES;
  @Nullable private static final MethodHandle GET_ATTRIBUTE_NAMES;

  static {
    Class<?> receiveMessageRequestClass = null;
    try {
      receiveMessageRequestClass =
          Class.forName("com.amazonaws.services.sqs.model.ReceiveMessageRequest");
    } catch (Throwable t) {
      // Ignore.
    }
    if (receiveMessageRequestClass != null) {
      MethodHandles.Lookup lookup = MethodHandles.publicLookup();
      MethodHandle withAttributeNames = null;
      try {
        withAttributeNames =
            lookup.findVirtual(
                receiveMessageRequestClass,
                "withAttributeNames",
                methodType(receiveMessageRequestClass, String[].class));
      } catch (NoSuchMethodException | IllegalAccessException e) {
        // Ignore
      }
      WITH_ATTRIBUTE_NAMES = withAttributeNames;

      MethodHandle getAttributeNames = null;
      try {
        getAttributeNames =
            lookup.findVirtual(
                receiveMessageRequestClass, "getAttributeNames", methodType(List.class));
      } catch (NoSuchMethodException | IllegalAccessException e) {
        // Ignore
      }
      GET_ATTRIBUTE_NAMES = getAttributeNames;
    } else {
      WITH_ATTRIBUTE_NAMES = null;
      GET_ATTRIBUTE_NAMES = null;
    }
  }

  static boolean isInstance(AmazonWebServiceRequest request) {
    return request
        .getClass()
        .getName()
        .equals("com.amazonaws.services.sqs.model.ReceiveMessageRequest");
  }

  static void withAttributeNames(AmazonWebServiceRequest request, String name) {
    if (WITH_ATTRIBUTE_NAMES == null) {
      return;
    }
    try {
      WITH_ATTRIBUTE_NAMES.invoke(request, name);
    } catch (Throwable throwable) {
      // Ignore
    }
  }

  static List<String> getAttributeNames(AmazonWebServiceRequest request) {
    if (GET_ATTRIBUTE_NAMES == null) {
      return Collections.emptyList();
    }
    try {
      return (List<String>) GET_ATTRIBUTE_NAMES.invoke(request);
    } catch (Throwable t) {
      return Collections.emptyList();
    }
  }

  private SqsReceiveMessageRequestAccess() {}
}

==> v1.22.x.zip: opentelemetry-java-instrumentation/instrumentation/aws-sdk/aws-sdk-2.2/library/src/main/java/io/opentelemetry/instrumentation/awssdk/v2_2/SqsReceiveMessageRequestAccess.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.instrumentation.awssdk.v2_2;

import static java.lang.invoke.MethodType.methodType;

import java.lang.invoke.MethodHandle;
import java.lang.invoke.MethodHandles;
import java.util.Collection;
import java.util.List;
import javax.annotation.Nullable;
import software.amazon.awssdk.core.SdkRequest;

/**
 * Reflective access to aws-sdk-java-sqs class ReceiveMessageRequest.
 *
 * <p>We currently don't have a good pattern of instrumenting a core library with various plugins
 * that need plugin-specific instrumentation - if we accessed the class directly, Muzzle would
 * prevent the entire instrumentation from loading when the plugin isn't available. We need to
 * carefully check this class has all reflection errors result in no-op, and in the future we will
 * hopefully come up with a better pattern.
 */
final class SqsReceiveMessageRequestAccess {

  @Nullable private static final MethodHandle ATTRIBUTE_NAMES_WITH_STRINGS;

  static {
    Class<?> receiveMessageRequestClass = null;
    try {
      receiveMessageRequestClass =
          Class.forName("software.amazon.awssdk.services.sqs.model.ReceiveMessageRequest$Builder");
    } catch (Throwable t) {
      // Ignore.
    }
    if (receiveMessageRequestClass != null) {
      MethodHandles.Lookup lookup = MethodHandles.publicLookup();
      MethodHandle withAttributeNames = null;
      try {
        withAttributeNames =
            lookup.findVirtual(
                receiveMessageRequestClass,
                "attributeNamesWithStrings",
                methodType(receiveMessageRequestClass, Collection.class));
      } catch (NoSuchMethodException | IllegalAccessException e) {
        // Ignore
      }
      ATTRIBUTE_NAMES_WITH_STRINGS = withAttributeNames;
    } else {
      ATTRIBUTE_NAMES_WITH_STRINGS = null;
    }
  }

  static boolean isInstance(SdkRequest request) {
    return request
        .getClass()
        .getName()
        .equals("software.amazon.awssdk.services.sqs.model.ReceiveMessageRequest");
  }

  static void attributeNamesWithStrings(SdkRequest.Builder builder, List<String> attributeNames) {
    if (ATTRIBUTE_NAMES_WITH_STRINGS == null) {
      return;
    }
    try {
      ATTRIBUTE_NAMES_WITH_STRINGS.invoke(builder, attributeNames);
    } catch (Throwable throwable) {
      // Ignore
    }
  }

  private SqsReceiveMessageRequestAccess() {}
}
